============
trame-simput
============

Simput implementation for trame


* Free software: Apache Software License


Installing
----------
Build and install the Vue components

.. code-block:: console

    cd vue-components
    npm i
    npm run build
    cd -

Install the application

.. code-block:: console

    pip install -e .



Features
--------

* TODO
